@@ -37,7 +37,7 @@ use chrono::offset::Utc;
 use chrono::DateTime;
 
 pub use ebml::MatroskaError;
-use ebml::{Element, ElementType, MResult};
+use ebml::{Element, ElementType, Result};
 
 /// A Matroska file
 #[derive(Debug)]
@@ -66,7 +66,7 @@ impl Matroska {
     }
 
     /// Parses contents of open Matroska file
-    pub fn open(mut file: File) -> MResult<Matroska> {
+    pub fn open(mut file: File) -> Result<Matroska> {
         use std::io::Seek;
         use std::io::SeekFrom;
 
@@ -198,7 +198,7 @@ impl Seektable {
         self.seek.get(&id).cloned()
     }
 
-    fn parse(r: &mut dyn io::Read, size: u64) -> MResult<Seektable> {
+    fn parse(r: &mut dyn io::Read, size: u64) -> Result<Seektable> {
         let mut seektable = Seektable::new();
         for e in Element::parse_master(r, size)? {
             if let Element {
@@ -284,7 +284,7 @@ impl Info {
         }
     }
 
-    fn parse(r: &mut dyn io::Read, size: u64) -> MResult<Info> {
+    fn parse(r: &mut dyn io::Read, size: u64) -> Result<Info> {
         let mut info = Info::new();
         let mut timecode_scale = None;
         let mut duration = None;
@@ -393,7 +393,7 @@ impl Track {
         }
     }
 
-    fn parse(r: &mut dyn io::Read, size: u64) -> MResult<Vec<Track>> {
+    fn parse(r: &mut dyn io::Read, size: u64) -> Result<Vec<Track>> {
         Element::parse_master(r, size).map(|elements| {
             elements
                 .into_iter()
@@ -707,7 +707,7 @@ impl Attachment {
         }
     }
 
-    fn parse(r: &mut dyn io::Read, size: u64) -> MResult<Vec<Attachment>> {
+    fn parse(r: &mut dyn io::Read, size: u64) -> Result<Vec<Attachment>> {
         Element::parse_master(r, size).map(|elements| {
             elements
                 .into_iter()
@@ -785,7 +785,7 @@ impl ChapterEdition {
         }
     }
 
-    fn parse(r: &mut dyn io::Read, size: u64) -> MResult<Vec<ChapterEdition>> {
+    fn parse(r: &mut dyn io::Read, size: u64) -> Result<Vec<ChapterEdition>> {
         Element::parse_master(r, size).map(|elements| {
             elements
                 .into_iter()
@@ -978,7 +978,7 @@ impl Tag {
         }
     }
 
-    fn parse(r: &mut dyn io::Read, size: u64) -> MResult<Vec<Tag>> {
+    fn parse(r: &mut dyn io::Read, size: u64) -> Result<Vec<Tag>> {
         Element::parse_master(r, size).map(|elements| {
             elements
                 .into_iter()
@@ -1023,7 +1023,7 @@ impl Tag {
 #[derive(Debug)]
 pub struct Target {
     /// Logical level of target
-    pub target_type_value: Option<u64>,
+    pub target_type_value: Option<TargetTypeValue>,
     /// Informational string of target level
     pub target_type: Option<String>,
     /// Unique IDs of track(s) the tag belongs to
@@ -1036,6 +1036,65 @@ pub struct Target {
     pub attachment_uids: Vec<u64>,
 }
 
+/// The type of value the tag is for
+#[derive(Debug)]
+pub enum TargetTypeValue {
+    /// collection
+    Collection,
+    /// edition / issue / volume / opus / season / sequel
+    Season,
+    /// album / opera / concert / movie / episode / concert
+    Episode,
+    /// part / session
+    Part,
+    /// track / song / chapter
+    Chapter,
+    /// subtrack / part / movement / scene
+    Scene,
+    /// shot
+    Shot,
+    /// none of the define value types
+    Unknown,
+}
+
+impl TargetTypeValue {
+    /// Returns type value as static string
+    pub fn as_str(&self) -> &'static str {
+        match self {
+            TargetTypeValue::Collection => "collection",
+            TargetTypeValue::Season => "season",
+            TargetTypeValue::Episode => "episode",
+            TargetTypeValue::Part => "part",
+            TargetTypeValue::Chapter => "chapter",
+            TargetTypeValue::Scene => "scene",
+            TargetTypeValue::Shot => "shot",
+            TargetTypeValue::Unknown => "unknown",
+        }
+    }
+}
+
+impl std::fmt::Display for TargetTypeValue {
+    #[inline]
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::result::Result<(), std::fmt::Error> {
+        write!(f, "{}", self.as_str())
+    }
+}
+
+impl From<u64> for TargetTypeValue {
+    fn from(val: u64) -> Self {
+        match val {
+            70 => TargetTypeValue::Collection,
+            60 => TargetTypeValue::Season,
+            50 => TargetTypeValue::Episode,
+            40 => TargetTypeValue::Part,
+            30 => TargetTypeValue::Chapter,
+            20 => TargetTypeValue::Scene,
+            10 => TargetTypeValue::Shot,
+            _ => TargetTypeValue::Unknown,
+        }
+    }
+}
+
 impl Target {
     fn new() -> Target {
         Target {
@@ -1057,7 +1116,7 @@ impl Target {
                     val: ElementType::UInt(number),
                     ..
                 } => {
-                    target.target_type_value = Some(number);
+                    target.target_type_value = Some(number.into());
                 }
                 Element {
                     id: ids::TARGETTYPE,
